@@ -58,7 +58,8 @@ const ApplicationMenuItem = new Lang.Class({
         this._iconBin = new St.Bin();
         this.actor.add_child(this._iconBin);
 
-        let appLabel = new St.Label({ text: app.get_name() });
+        let appLabel = new St.Label({ text: app.get_name(), y_expand: true,
+                                      y_align: Clutter.ActorAlign.CENTER });
         this.actor.add_child(appLabel, { expand: true });
         this.actor.label_actor = appLabel;
 
@@ -283,9 +284,7 @@ const ApplicationsButton = new Lang.Class({
                                      y_expand: true,
                                      y_align: Clutter.ActorAlign.CENTER });
         hbox.add_child(this._label);
-        hbox.add_child(new St.Label({ text: '\u25BE',
-                                      y_expand: true,
-                                      y_align: Clutter.ActorAlign.CENTER }));
+        hbox.add_child(PopupMenu.arrowIcon(St.Side.BOTTOM));
 
         this.actor.add_actor(hbox);
         this.actor.name = 'panelApplications';
@@ -590,8 +589,8 @@ function enable() {
     Main.panel.addToStatusArea('apps-menu', appsMenuButton, 1, 'left');
 
     Main.wm.setCustomKeybindingHandler('panel-main-menu',
-                                       Shell.KeyBindingMode.NORMAL |
-                                       Shell.KeyBindingMode.OVERVIEW,
+                                       Shell.ActionMode.NORMAL |
+                                       Shell.ActionMode.OVERVIEW,
                                        function() {
                                            appsMenuButton.menu.toggle();
                                        });
@@ -607,8 +606,8 @@ function disable() {
     activitiesButton.container.show();
 
     Main.wm.setCustomKeybindingHandler('panel-main-menu',
-                                       Shell.KeyBindingMode.NORMAL |
-                                       Shell.KeyBindingMode.OVERVIEW,
+                                       Shell.ActionMode.NORMAL |
+                                       Shell.ActionMode.OVERVIEW,
                                        Main.sessionMode.hasOverview ?
                                        Lang.bind(Main.overview, Main.overview.toggle) :
                                        null);
